#version 330
//uniform vec2 LightPosition;			// Position of the light on the screen
uniform sampler2D lightshaftMap;		// The Occlusion Map texture
uniform sampler2D diffuseTexture;		// The Scene Render texture

const int NUM_SAMPLES = 150;		// How many steps between this fragment and the light position
const float EXPOSURE = 0.0225;		// How bright the light will be
const float DECAY = 1.0;			// How much the brightness decays over distance
const float DENSITY = 1.0;			// How much the illumination decays after each sample
const float WEIGHT = 0.75;			// How much each sample is weighted

in vec2 TexCoord;					// Where in the texture is this fragment
	
out vec4 fragColor;					// End colour

void main() 
{

	vec2 LightPosition = vec2(15, -11); 
	float illuminationDecay = 1.0;
	// Find how much distance we'll travel per sample
	vec2 deltaTexCoord= TexCoord - LightPosition;
	deltaTexCoord *= 1.0 / float(NUM_SAMPLES) * DENSITY;
	
	// Start at the current location of the fragment
	vec2 currentTexCoord = TexCoord;
	
	// By default no samples have been read
	vec4 color = vec4(0);
	
	// Read each sample between the fragment and the light position to find out the colouring
	for (int i = 0; i < NUM_SAMPLES; i++) {
		currentTexCoord -= deltaTexCoord;
		vec4 occlusionSample = texture2D(lightshaftMap, currentTexCoord);
		occlusionSample *= illuminationDecay * WEIGHT;
		color += occlusionSample;
		illuminationDecay *= DECAY;
	}
	
	// Adjust the brightness
	color *= EXPOSURE;
	
	// Read the colour from the scene render
	color += texture2D(diffuseTexture, TexCoord);
	
	// Clamp the colour and send it off
	fragColor = clamp(color, vec4(0), vec4(1));
}
