#version 330

uniform sampler2D diffuseTexture;
uniform sampler2D shadowMap;
//uniform vec3 lightPosition_worldspace;

in vec2 UVs;
in vec3 position_worldspace;
in vec3 normal_cameraspace;
in vec3 eyeDirection_cameraspace;
in vec3 lightDirection_cameraspace;
in vec4 ShadowCoord; 
out vec4 fragColor;

void main()
{
	
	float visibility = 1.0;
	
	if (texture(shadowMap, ShadowCoord.xy).z  <  ShadowCoord.z){
		visibility = 0.0;
	}
	
	vec3 lightPosition_worldspace = vec3(0.0, 5.0, -11.4255); 
	vec3 color = vec3(1,1,1);
	float lightIntensity = 70.0f;
	
	vec3 MaterialDiffuseColor = texture(diffuseTexture, UVs).rgb;
	vec3 MaterialAmbientColor = vec3(0.5,0.5,0.5) * MaterialDiffuseColor;
	vec3 MaterialSpecularColor = vec3(0.5,0.5,0.5);

	float distance = length( lightPosition_worldspace - position_worldspace );
	vec3 n = normalize( normal_cameraspace );
	vec3 l = normalize( lightDirection_cameraspace );
	float cosTheta = clamp(dot(n,l), 0, 1);
	
	vec3 E = normalize(eyeDirection_cameraspace);
	vec3 R = reflect(-l,n);
	float cosAlpha = clamp( dot( E,R ), 0,1 );


	fragColor.rgb = 
		MaterialAmbientColor +  
		visibility * MaterialDiffuseColor * color * lightIntensity * cosTheta / (distance*distance) + 
		visibility * MaterialSpecularColor * color * lightIntensity   * pow(cosAlpha,5) / (distance*distance);
	fragColor.a=1;

		
}